@@ -51,6 +51,10 @@ class Pyctuator:
 
         * Flask - `app` is an instance of `flask.app.Flask`
 
+        * aiohttp - `app` is an instance of `aiohttp.web.Application`
+
+        * Tornado - `app` is an instance of `tornado.web.Application`
+
         :param app: an instance of a supported web-framework with which the pyctuator endpoints will be registered
         :param app_name: the application's name that will be presented in the "Info" section in boot-admin
         :param app_description: a description that will be presented in the "Info" section in boot-admin
@@ -87,12 +91,19 @@ class Pyctuator:
         self.boot_admin_registration_handler: Optional[BootAdminRegistrationHandler] = None
 
         root_logger = logging.getLogger()
+        # If application did not initiate logging module, add default handler to root logger
+        # logging.info implicitly calls logging.basicConfig(), see logging.basicConfig in Python's documentation.
+        if not root_logger.hasHandlers():
+            logging.info("Logging not configured, using logging.basicConfig()")
+
         root_logger.addHandler(self.pyctuator_impl.logfile.log_messages)
 
         # Find and initialize an integration layer between the web-framework adn pyctuator
         framework_integrations = {
             "flask": self._integrate_flask,
             "fastapi": self._integrate_fastapi,
+            "aiohttp": self._integrate_aiohttp,
+            "tornado": self._integrate_tornado
         }
         for framework_name, framework_integration_function in framework_integrations.items():
             if self._is_framework_installed(framework_name):
@@ -119,7 +130,7 @@ class Pyctuator:
                     return
 
         # Fail in case no framework was found for the target app
-        raise EnvironmentError("No framework was found that is matching the target app"
+        raise EnvironmentError("No framework was found that is matching the target app "
                                "(is it properly installed and imported?)")
 
     def stop(self) -> None:
@@ -174,3 +185,29 @@ class Pyctuator:
             FlaskPyctuator(app, pyctuator_impl)
             return True
         return False
+
+    def _integrate_aiohttp(self, app: Any, pyctuator_impl: PyctuatorImpl) -> bool:
+        """
+        This method should only be called if we detected that aiohttp is installed.
+        It will then check whether the given app is a aiohttp app, and if so - it will add the Pyctuator
+        endpoints to it.
+        """
+        from aiohttp.web import Application
+        if isinstance(app, Application):
+            from pyctuator.impl.aiohttp_pyctuator import AioHttpPyctuator
+            AioHttpPyctuator(app, pyctuator_impl)
+            return True
+        return False
+
+    def _integrate_tornado(self, app: Any, pyctuator_impl: PyctuatorImpl) -> bool:
+        """
+        This method should only be called if we detected that tornado is installed.
+        It will then check whether the given app is a tornado app, and if so - it will add the Pyctuator
+        endpoints to it.
+        """
+        from tornado.web import Application
+        if isinstance(app, Application):
+            from pyctuator.impl.tornado_pyctuator import TornadoHttpPyctuator
+            TornadoHttpPyctuator(app, pyctuator_impl)
+            return True
+        return False
